const BotDetector = require("../lib/index");

describe("BotDetector", () => {
  let detector;

  beforeEach(() => {
    detector = new BotDetector();
  });

  it("should detect a bot by User-Agent", () => {
    const req = {
      headers: {
        "user-agent": "BadBot",
      },
      socket: {
        remoteAddress: "127.0.0.1",
      },
    };

    const result = detector.detect(req);
    expect(result.isBot).toBe(true);
    expect(result.reason).toBe("Bot-like User-Agent");
  });

  it("should not detect a bot for a normal browser request", () => {
    const req = {
      headers: {
        "user-agent":
          "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36",
      },
      socket: {
        remoteAddress: "127.0.0.1",
      },
    };

    const result = detector.detect(req);
    expect(result.isBot).toBe(false);
    expect(result.reason).toBe("No suspicious activity");
  });

  it("should detect a bot by excessive request rate", () => {
    // This test should be updated with specific logic
    // For example, simulating multiple requests and checking if it's marked as a bot
  });
});
